==> xcin-2.5.0.tar.gz: xcin-2.5/src/include/constant.h <==
/*
 * $Id: constant.h,v 1.2 1999/02/18 08:09:23 thhsieh Exp $
 */
/*
    Copyright (C) 1999 by  XCIN TEAM

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    For any question or suggestion, please mail to xcin mailing-list:
    xcin@linux.org.tw, or the maintainer Tung-Han Hsieh: thhsieh@linux.org.tw
*/      

#ifndef  _CONSTANT_H
#define  _CONSTANT_H

#include "config.h"

#define  XCIN_VERSION  		"xcin 2.5.0"
#define  MODULE_VERSION		"19990609"

#ifndef XCIN_DEFAULT_RCDIR
#define  XCIN_DEFAULT_RCDIR	"/usr/local/etc"
#endif
#ifndef XCIN_DEFAULT_DIR
#define  XCIN_DEFAULT_DIR	"/usr/local/lib/xcin"
#endif
#define  XCIN_DEFAULT_RC  	"xcinrc"
#define  XCIN_USER_DIR		".xcin"
#define  LOCALE_NAME		"zh_TW.Big5"

#define  MAX_INP_ENTRY		12	/* tγ̦hJk */
#define  MIN_WIN_WIDTH		40	/* Min window width. */
#define  MAX_WIN_WIDTH		100	/* Max window width. */

#define  CIN_ENAME_LENGTH       20	/* Jk^W٪̤j */
#define  CIN_CNAME_LENGTH       20	/* JkW٪̤j */
#define  SELECT_KEY_LENGTH      15	/* Цr̤jƥ */
#define  END_KEY_LENGTH         10	/* ̦hiHXӡuv */
#define  QUICK_KEY_NCHARS	20	/* ֱieǪr */

#define  N_CCODE_RULE    	5	/* XdWhƥ (for byte code) */
#define  N_KEYCODE		50	/* iΪr: 0-9, a-z, .... */
#define  N_ASCII_KEY            95      /* Num of printable ASCII char */


#endif

==> xcin_2.5.2.orig.tar.gz: xcin-2.5/src/include/constant.h <==
/*
    Copyright (C) 1999 by  XCIN TEAM

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    For any question or suggestion, please mail to xcin mailing-list:
    xcin@linux.org.tw, or the maintainer Tung-Han Hsieh: thhsieh@linux.org.tw
*/      

#ifndef  _CONSTANT_H
#define  _CONSTANT_H

#define  XCIN_VERSION  		"xcin 2.5.2"

#ifndef  XCIN_DEFAULT_RCDIR
#define  XCIN_DEFAULT_RCDIR	"/usr/local/etc"
#endif
#ifndef  XCIN_DEFAULT_DIR
#define  XCIN_DEFAULT_DIR	"/usr/local/lib/xcin"
#endif
#ifndef  XCIN_MSGLOCAT
#define  XCIN_MSGLOCAT		"/usr/local/share/locale"
#endif 
#define  XCIN_DEFAULT_RC  	"xcinrc"
#define  XCIN_USER_DIR		".xcin"
#define  LOCALE_NAME		"zh_TW.Big5"
#define  DEFAULT_XIMNAME 	"xcin"

#define  MIN_WIN_WIDTH		40	/* Min window width. */
#define  MIN_WIN_WIDTH2		10	/* Min window2 width. */
#define  MAX_WIN_WIDTH		100	/* Max window width. */

#endif
